==> alg-common-1.17.3-20190619.070102-1-sources.jar: cn/com/duiba/nezha/alg/common/model/slotmaterialselect/SlotMaterialModel.java <==
package cn.com.duiba.nezha.alg.common.model.slotmaterialselect;

/**
 * Created by Administrator on 2019/2/19.
 */
public class SlotMaterialModel {
        long materialId;
        long slotId;
        long appId;
        double alpha = 1.5; //模型参数
        double beta = 2; // 模型参数
        double reward = 0; //模型参数
        double count = 0; //模型参数
        long updateTime = 0;//修改时间

    public long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(long materialId) {
        this.materialId = materialId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }

    public double getAlpha() {
        return alpha;
    }

    public void setAlpha(double alpha) {
        this.alpha = alpha;
    }

    public double getBeta() {
        return beta;
    }

    public void setBeta(double beta) {
        this.beta = beta;
    }

    public double getReward() {
        return reward;
    }

    public void setReward(double reward) {
        this.reward = reward;
    }

    public double getCount() {
        return count;
    }

    public void setCount(double count) {
        this.count = count;
    }

    public long getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(long updateTime) {
        this.updateTime = updateTime;
    }
}

==> alg-common-2.4.11-20190801.073039-1-sources.jar: cn/com/duiba/nezha/alg/common/model/slotmaterialselect/SlotMaterialModel.java <==
package cn.com.duiba.nezha.alg.common.model.slotmaterialselect;

/**
 * Created by Administrator on 2019/2/19.
 */
public class SlotMaterialModel {
    long materialId;
    long slotId;
    long appId;
    double alpha = 1.5; //模型参数
    double beta = 2; // 模型参数
    double reward = 0; //模型参数
    double count = 0; //模型参数
    double matchScore = 0; //模型参数
    double nCtr = 0; //模型参数
    double nPartRate = 0; //模型参数
    int type; //SDK=1，API=2
    long updateTime = 0;//修改时间

    public long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(long materialId) {
        this.materialId = materialId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }

    public double getAlpha() {
        return alpha;
    }

    public void setAlpha(double alpha) {
        this.alpha = alpha;
    }

    public double getBeta() {
        return beta;
    }

    public void setBeta(double beta) {
        this.beta = beta;
    }

    public double getReward() {
        return reward;
    }

    public void setReward(double reward) {
        this.reward = reward;
    }

    public double getCount() {
        return count;
    }

    public void setCount(double count) {
        this.count = count;
    }

    public long getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(long updateTime) {
        this.updateTime = updateTime;
    }

    public double getMatchScore() {
        return matchScore;
    }

    public void setMatchScore(double matchScore) {
        this.matchScore = matchScore;
    }

    public double getnCtr() {
        return nCtr;
    }

    public void setnCtr(double nCtr) {
        this.nCtr = nCtr;
    }

    public double getnPartRate() {
        return nPartRate;
    }

    public void setnPartRate(double nPartRate) {
        this.nPartRate = nPartRate;
    }

    public int getType() {
        return type;
    }

    public void setType(int type) {
        this.type = type;
    }
}
